@@ -8,7 +8,7 @@ from ssh_client.helpers import remote_bat_file, generate_inmemory_file, generate
 
 
 RELATIVE_REMOTE_DIR = "bat_runner"
-ABSOLUTE_REMOTE_DIR = f"C:\\Users\\Administrator\\{RELATIVE_REMOTE_DIR}"
+ABSOLUTE_REMOTE_DIR = f"C:\\Users\\Administrator\\Canper\\{RELATIVE_REMOTE_DIR}"
 HOST = environ.get('REMOTE_HOST')
 USER = environ.get('REMOTE_USER')
 PASSWORD = environ.get('REMOTE_PASSWORD')
